@@ -14,16 +14,6 @@ setClass("RandomParam", contains="BiocSingularParam", slots=c(args="list"))
 #' @export
 setClass("FastAutoParam", contains="BiocSingularParam")
 
-#' @export
-setClass("DeferredMatrixSeed", slots=c(.matrix="ANY", center="numeric", scale="numeric", use_center="logical", use_scale="logical", transposed="logical"))
-
-#' @export
-#' @importClassesFrom DelayedArray DelayedMatrix
-setClass("DeferredMatrix",
-    contains="DelayedMatrix",
-    representation(seed="DeferredMatrixSeed")
-)
-
 #' @export
 setClass("LowRankMatrixSeed", slots=c(rotation="ANY", components="ANY"))
 
